@@ -15,13 +15,13 @@ class Call(Expression):
         args = ', '.join(str(x) for x in self.args)
         return f'{self.func}({args})'
 
-    def _compile(self, out):
+    def _compile(self, out, flags):
         args, kwargs = [], []
 
         for arg in self.args:
             is_kw = isinstance(arg, KeywordArg)
             expr = arg.expr if is_kw else arg
-            value = expr.argumentize(out)
+            value = expr.argumentize(out, flags)
 
             if is_kw:
                 kwargs.append((arg.name, value))
@@ -29,7 +29,13 @@ class Call(Expression):
                 args.append(value)
 
         _ParseFunction = Code('_ParseFunction')
-        func = _ParseFunction(Code(self.func.resolved), tuple(args), tuple(kwargs))
+
+        if flags.uses_context and not self.func.is_local:
+            resolved_func = f'_ctx.{self.func.resolved}'
+        else:
+            resolved_func = self.func.resolved
+
+        func = _ParseFunction(Code(resolved_func), tuple(args), tuple(kwargs))
         func = out.var('func', func)
         out += (STATUS, RESULT, POS) << Yield((CALL, func, POS))
 
